@@ -574,12 +574,12 @@ class TgWrap():
                                     changes[module]["other"].append(action)
 
                         if ts_config:
-                            changes[module]["unauhhorized"] = run_terrasafe(
+                            changes[module]["unauthorized"] = run_terrasafe(
                                 config=ts_config,
                                 data=data,
                                 verbose=self.printer.print_verbose,
                                 )
-                            if len(changes[module]["unauhhorized"]) > 0:
+                            if len(changes[module]["unauthorized"]) > 0:
                                 ts_validation_successful = False
                     except json.decoder.JSONDecodeError as e:
                         raise Exception(
@@ -595,7 +595,7 @@ class TgWrap():
                 self.printer.success('- No changes detected')
             if value["unauthorized"]:
                 self.printer.error('- Unauthorized deletions:')
-                for m in value["unauhtorized"]:
+                for m in value["unauthorized"]:
                     self.printer.error(f' -> {m}')
             if value["deletions"]:
                 self.printer.warning('- Deletions:')
